You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by jm...@apache.org on 2015/12/28 05:59:47 UTC

[07/12] git commit: [flex-sdk] [refs/heads/develop] - add support for new versions of flash player

add support for new versions of flash player


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/1cef920c
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/1cef920c
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/1cef920c

Branch: refs/heads/develop
Commit: 1cef920c8435e4ba4a870d8aa07655475fc9838b
Parents: 450d1ae
Author: Justin Mclean <jm...@apache.org>
Authored: Mon Dec 28 13:46:23 2015 +1100
Committer: Justin Mclean <jm...@apache.org>
Committed: Mon Dec 28 13:46:23 2015 +1100

----------------------------------------------------------------------
 ide/addAIRtoSDK.sh           | 26 ++++++++++++++++++++------
 ide/checkAllPlayerGlobals.sh |  4 +++-
 ide/setFlashPlayerVersion.sh | 16 ++++++----------
 3 files changed, 29 insertions(+), 17 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/1cef920c/ide/addAIRtoSDK.sh
----------------------------------------------------------------------
diff --git a/ide/checkAllPlayerGlobals.sh b/ide/checkAllPlayerGlobals.sh
index 0f2e36e..1b68aa9 100755
--- a/ide/checkAllPlayerGlobals.sh
+++ b/ide/checkAllPlayerGlobals.sh
@@ -126,4 +126,6 @@ downloadPlayerGlobal 14.0 6858e63b1ff8373a1a3c1c60b36c9fc9 http://download.macro
 downloadPlayerGlobal 15.0 4d17b14ef74dd23377a71a3fdbfda8ad http://download.macromedia.com/get/flashplayer/updaters/15/playerglobal15_0.swc
 downloadPlayerGlobal 16.0 336be79e5b3ed665c98308241381aff3 http://download.macromedia.com/get/flashplayer/updaters/16/playerglobal16_0.swc
 downloadPlayerGlobal 17.0 1a5e68003b5ce6af08f3841bdb2b96ee http://download.macromedia.com/get/flashplayer/updaters/17/playerglobal17_0.swc
-downloadPlayerGlobal 17.0b 2bd048da880ab3b9516bdf1f263a3135 http://labsdownload.adobe.com/pub/labs/flashruntimes/flashplayer/flashplayer17_playerglobal.swc
+downloadPlayerGlobal 18.0 af3459e5beb554e58fe4d8582e5fae20 http://download.macromedia.com/get/flashplayer/updaters/17/playerglobal18_0.swc
+downloadPlayerGlobal 19.0 680a08d16f4b74de2648e956bde3c87b http://download.macromedia.com/get/flashplayer/updaters/17/playerglobal19_0.swc
+downloadPlayerGlobal 20.0 8f51be6cf9ed743bab90d5aaca37fb05 http://download.macromedia.com/get/flashplayer/updaters/17/playerglobal20_0.swc

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/1cef920c/ide/setFlashPlayerVersion.sh
----------------------------------------------------------------------
diff --git a/ide/setFlashPlayerVersion.sh b/ide/setFlashPlayerVersion.sh
index 82aa92c..94de920 100755
--- a/ide/setFlashPlayerVersion.sh
+++ b/ide/setFlashPlayerVersion.sh
@@ -99,20 +99,15 @@ determineVersion()
         then 
             FLASH_VERSION="11.1"
         else
-            FLASH_VERSION="17.0"
+            FLASH_VERSION="20.0"
         fi
     fi
     
     if [ ${latest} = "Y" ]
     then
-    	FLASH_VERSION="17.0"
+    	FLASH_VERSION="20.0"
     fi
-    
-    if [ ${useBeta} = "Y" ]
-    then
-    	FLASH_VERSION="17.0b"
-    fi
-    
+
     echo "Setting minimum Flash Player version to ${FLASH_VERSION}"
     echo
     echo
@@ -129,9 +124,10 @@ if [[ "${FLASH_VERSION}" != "10.2" && "${FLASH_VERSION}" != "10.3"  && "${FLASH_
   && "${FLASH_VERSION}" != "11.7" && "${FLASH_VERSION}" != "11.8" && "${FLASH_VERSION}" != "11.9"
   && "${FLASH_VERSION}" != "12.0" && "${FLASH_VERSION}" != "13.0" && "${FLASH_VERSION}" != "14.0"
   && "${FLASH_VERSION}" != "15.0" && "${FLASH_VERSION}" != "16.0" && "${FLASH_VERSION}" != "17.0"
-  && "${FLASH_VERSION}" != "17.0b" ]]
+  && "${FLASH_VERSION}" != "17.0" && "${FLASH_VERSION}" != "18.0" && "${FLASH_VERSION}" != "19.0"
+  && "${FLASH_VERSION}" != "20.0" ]]
 then
-	echo Unknown version ${FLASH_VERSION} of Flash Player. Versions 10.2, 10.3, 11.0, 11.1, 11.2, 11.3, 11.4, 11.5, 11.6, 11.7, 11.8, 11.9, 12.0, 13.0, 14.0, 15.0, 16.0 and 17.0 are supported.
+	echo Unknown version ${FLASH_VERSION} of Flash Player. Versions 10.2, 10.3, 11.0, 11.1, 11.2, 11.3, 11.4, 11.5, 11.6, 11.7, 11.8, 11.9, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0 and 20.0 are supported.
 	exit 1;
 fi
diff --git a/ide/addAIRtoSDK.sh b/ide/addAIRtoSDK.sh
index 4519333..aeb7575 100755
--- a/ide/addAIRtoSDK.sh
+++ b/ide/addAIRtoSDK.sh
@@ -30,7 +30,7 @@
 AIR_VERSION="$1"
 OS=`uname`
 
-if [[ "${AIR_VERSION}" != "17.0b"
+if [[ "${AIR_VERSION}" != "20.0"  && "${AIR_VERSION}" != "19.0"  && "${AIR_VERSION}" != "18.0"
   && "${AIR_VERSION}" != "17.0" && "${AIR_VERSION}" != "16.0" && "${AIR_VERSION}" != "15.0" 
   && "${AIR_VERSION}" != "14.0" && "${AIR_VERSION}" != "13.0" && "${AIR_VERSION}" != "4.0" 
   && "${AIR_VERSION}" != "3.9" && "${AIR_VERSION}" != "3.8" && "${AIR_VERSION}" != "3.7" 
@@ -38,7 +38,7 @@ if [[ "${AIR_VERSION}" != "17.0b"
   && "${AIR_VERSION}" != "3.3" && "${AIR_VERSION}" != "3.2" && "${AIR_VERSION}" != "3.1" 
   && "${AIR_VERSION}" != "3.0" && "${AIR_VERSION}" != "2.7" && "${AIR_VERSION}" != "2.6" ]]
 then
-	echo Unknown version ${AIR_VERISON} of AIR. Versions 2.6, 2.7, 3.0, 3.1, 3.2, 3.3, 3.4, 3.5, 3.6, 3.7, 3.8, 3.9, 4.0, 13.0, 14.0, 15.0, 16.0 and 17.0 are supported.
+	echo Unknown version ${AIR_VERISON} of AIR. Versions 2.6, 2.7, 3.0, 3.1, 3.2, 3.3, 3.4, 3.5, 3.6, 3.7, 3.8, 3.9, 4.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0 and 20.0 are supported.
 	exit 1;
 fi
 
@@ -161,12 +161,26 @@ updatePlayerDescription "${AIR_VERSION}" "${IDE_SDK_DIR}/flex-sdk-description.xm
 for configFile in "${configFiles[@]}"
 do
 	echo Updating ${configFile}
+	
+	# 20.0 needs FP 20 and swf version 31
+	if [ ${AIR_VERSION} = "20.0" ]
+	then
+		updatePlayerVersion 20.0 "${configFile}"
+		updateSWFVersion 31 "${configFile}"
+	fi
+	
+	# 19.0 needs FP 19 and swf version 30
+	if [ ${AIR_VERSION} = "19.0" ]
+	then
+		updatePlayerVersion 19.0 "${configFile}"
+		updateSWFVersion 30 "${configFile}"
+	fi
 
-	# 17.0 beta needs FP 17 and swf version 28
-	if [ ${AIR_VERSION} = "17.0b" ]
+	# 18.0 needs FP 18 and swf version 29
+	if [ ${AIR_VERSION} = "18.0" ]
 	then
-		updatePlayerVersion 17.0 "${configFile}"
-		updateSWFVersion 28 "${configFile}"
+		updatePlayerVersion 18.0 "${configFile}"
+		updateSWFVersion 29 "${configFile}"
 	fi	
 	
 	# 17.0 needs FP 17 and swf version 28

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/1cef920c/ide/checkAllPlayerGlobals.sh
----------------------------------------------------------------------